-- Deploy camper:available_countries to pg
-- requires: schema_camper
-- requires: country
-- requires: country_i18n

begin;

-- Downloaded from https://www.ecb.europa.eu/stats/money_credit_banking/anacredit/html/index.en.html
-- Last updated 2022-07-29.
-- Names come from Unicode’s Common Locale Data Repository (CLDR).
insert into camper.country
(country_code, name, postal_code_regex)
values ('AF', 'Afghanistan', '\d{4}')
     , ('AX', 'Åland Islands', '.{1,255}')
     , ('AL', 'Albania', '\d{4}')
     , ('DZ', 'Algeria', '\d{5}')
     , ('AS', 'American Samoa', '967\d{2}(-\d{4})?')
     , ('AD', 'Andorra', 'AD\d{3}')
     , ('AO', 'Angola', '.{1,255}')
     , ('AI', 'Anguilla', '(AI-2640)')
     , ('AQ', 'Antarctica', '(7151)')
     , ('AG', 'Antigua and Barbuda', '.{1,255}')
     , ('AR', 'Argentina', '([A-Z]\d{4}[A-Z]{3})|([A-Z]\d{4})')
     , ('AM', 'Armenia', '(\d{4})|(\d{6})')
     , ('AW', 'Aruba', '.{1,255}')
     , ('AU', 'Australia', '\d{4}')
     , ('AT', 'Austria', '\d{4}')
     , ('AZ', 'Azerbaijan', '(AZ)(\d{4})|(AZ )(\d{4})')
     , ('BS', 'Bahamas', '.{1,255}')
     , ('BH', 'Bahrain', '\d{3}\d?')
     , ('BD', 'Bangladesh', '\d{4}')
     , ('BB', 'Barbados', 'BB\d{5}')
     , ('BY', 'Belarus', '\d{6}')
     , ('BE', 'Belgium', '\d{4}')
     , ('PW', 'Belau', '(96939|96940)')
     , ('BZ', 'Belize', '.{1,255}')
     , ('BJ', 'Benin', '.{1,255}')
     , ('BM', 'Bermuda', '[A-Z]{2} \d{2}')
     , ('BT', 'Bhutan', '\d{5}')
     , ('BO', 'Bolivia', '.{1,255}')
     , ('BQ', 'Bonaire, Saint Eustatius and Saba', '.{1,255}')
     , ('BA', 'Bosnia and Herzegovina', '\d{5}')
     , ('BW', 'Botswana', '.{1,255}')
     , ('BV', 'Bouvet Island', '.{1,255}')
     , ('BR', 'Brazil', '[0-9]{5}-[0-9]{3}')
     , ('IO', 'British Indian Ocean Territory', '(BB9D 1ZZ)')
     , ('BN', 'Brunei', '[A-Z]{2}\d{4}')
     , ('BG', 'Bulgaria', '\d{4}')
     , ('BF', 'Burkina Faso', '[1-9]\d{4}')
     , ('BI', 'Burundi', '.{1,255}')
     , ('KH', 'Cambodia', '\d{5,6}')
     , ('CM', 'Cameroon', '.{1,255}')
     , ('CA', 'Canada', '[A-Z][0-9][A-Z] [0-9][A-Z][0-9]')
     , ('CV', 'Cape Verde', '\d{4}')
     , ('KY', 'Cayman Islands', '[K][Y][0-9]{1}[-]([0-9]){4}')
     , ('CF', 'Central African Republic', '.{1,255}')
     , ('TD', 'Chad', '.{1,255}')
     , ('CL', 'Chile', '\d{7}')
     , ('CN', 'China', '\d{6}')
     , ('CX', 'Christmas Island', '(6798)')
     , ('CC', 'Cocos (Keeling) Islands', '(6799)')
     , ('CO', 'Colombia', '\d{6}')
     , ('KM', 'Comoros', '.{1,255}')
     , ('CG', 'Congo (Brazzaville)', '.{1,255}')
     , ('CD', 'Congo (Kinshasa)', '.{1,255}')
     , ('CK', 'Cook Islands', '.{1,255}')
     , ('CR', 'Costa Rica', '\d{5}')
     , ('HR', 'Croatia', '[1-5]\d{4}')
     , ('CU', 'Cuba', '(CP)?\d{5}')
     , ('CW', 'Curaçao', '.{1,255}')
     , ('CY', 'Cyprus', '[1-9]\d{3}')
     , ('CZ', 'Czech Republic', '[1-7][0-9]{2} [0-9]{2}|[1-7][0-9]{4}')
     , ('DK', 'Denmark', '\d{4}')
     , ('DJ', 'Djibouti', '.{1,255}')
     , ('DM', 'Dominica', '.{1,255}')
     , ('DO', 'Dominican Republic', '\d{5}')
     , ('EC', 'Ecuador', '\d{6}')
     , ('EG', 'Egypt', '\d{5}')
     , ('SV', 'El Salvador', '\d{4}')
     , ('GQ', 'Equatorial Guinea', '.{1,255}')
     , ('ER', 'Eritrea', '.{1,255}')
     , ('EE', 'Estonia', '\d{5}')
     , ('ET', 'Ethiopia', '\d{4}')
     , ('FK', 'Falkland Islands', '(FIQQ 1ZZ)')
     , ('FO', 'Faroe Islands', '\d{3}')
     , ('FJ', 'Fiji', '.{1,255}')
     , ('FI', 'Finland', '\d{5}')
     , ('FR', 'France', '\d{5}')
     , ('GF', 'French Guiana', '.{1,255}')
     , ('PF', 'French Polynesia', '((987)\d{2})')
     , ('TF', 'French Southern Territories', '.{1,255}')
     , ('GA', 'Gabon', '.{1,255}')
     , ('GM', 'Gambia', '.{1,255}')
     , ('GE', 'Georgia', '\d{4}')
     , ('DE', 'Germany', '\d{5}')
     , ('GH', 'Ghana', '.{1,255}')
     , ('GI', 'Gibraltar', '(GX11 1AA)')
     , ('GR', 'Greece', '(\d{3}) \d{2}|\d{5}')
     , ('GL', 'Greenland', '39\d{2}')
     , ('GD', 'Grenada', '.{1,255}')
     , ('GP', 'Guadeloupe', '.{1,255}')
     , ('GU', 'Guam', '((969)[1-3][0-2])(-\d{4})?')
     , ('GT', 'Guatemala', '\d{5}')
     , ('GG', 'Guernsey', '(GY)([0-9][0-9A-HJKPS-UW]?|[A-HK-Y][0-9][0-9ABEHMNPRV-Y]?) [0-9][ABD-HJLNP-UW-Z]{2}')
     , ('GN', 'Guinea', '\d{3}')
     , ('GW', 'Guinea-Bissau', '\d{4}')
     , ('GY', 'Guyana', '.{1,255}')
     , ('HT', 'Haiti', '(HT)(\d{4})|(HT) (\d{4})')
     , ('HM', 'Heard Island and McDonald Islands', '(7151)')
     , ('HN', 'Honduras', '\d{5}')
     , ('HK', 'Hong Kong', '(999077)')
     , ('HU', 'Hungary', '[1-9]\d{3}')
     , ('IS', 'Iceland', '[1-9]\d{2}')
     , ('IN', 'India', '[1-9]\d{5}')
     , ('ID', 'Indonesia', '[1-9]\d{4}')
     , ('IR', 'Iran', '\d{5}[\-]?\d{5}')
     , ('IQ', 'Iraq', '\d{5}')
     , ('IE', 'Ireland', '.{1,255}')
     , ('IM', 'Isle of Man', '(IM)([0-9][0-9A-HJKPS-UW]?|[A-HK-Y][0-9][0-9ABEHMNPRV-Y]?) [0-9][ABD-HJLNP-UW-Z]{2}')
     , ('IL', 'Israel', '\d{7}')
     , ('IT', 'Italy', '\d{5}')
     , ('CI', 'Ivory Coast', '.{1,255}')
     , ('JM', 'Jamaica', '(JM)[A-Z]{3}\d{2}')
     , ('JP', 'Japan', '(\d{3}-\d{4})')
     , ('JE', 'Jersey', 'JE[0-9]{1}[\s]([\d][A-Z]{2})')
     , ('JO', 'Jordan', '\d{5}')
     , ('KZ', 'Kazakhstan', '([A-Z]\d{2}[A-Z]\d[A-Z]\d)|(\d{6})')
     , ('KE', 'Kenya', '\d{5}')
     , ('KI', 'Kiribati', 'KI\d{4}')
     , ('KW', 'Kuwait', '\d{5}')
     , ('KG', 'Kyrgyzstan', '\d{6}')
     , ('LA', 'Laos', '\d{5}')
     , ('LV', 'Latvia', '((LV)[\-])?(\d{4})')
     , ('LB', 'Lebanon', '\d{4}( \d{4})?')
     , ('LS', 'Lesotho', '\d{3}')
     , ('LR', 'Liberia', '\d{4}')
     , ('LY', 'Libya', '.{1,255}')
     , ('LI', 'Liechtenstein', '\d{4}')
     , ('LT', 'Lithuania', '((LT)[\-])?(\d{5})')
     , ('LU', 'Luxembourg', '((L)[\-])?(\d{4})')
     , ('MO', 'Macao', '.{1,255}')
     , ('MK', 'North Macedonia', '\d{4}')
     , ('MG', 'Madagascar', '\d{3}')
     , ('MW', 'Malawi', '\d{6}')
     , ('MY', 'Malaysia', '\d{5}')
     , ('MV', 'Maldives', '\d{5}')
     , ('ML', 'Mali', '.{1,255}')
     , ('MT', 'Malta', '[A-Z]{3} [0-9]{4}|[A-Z]{2}[0-9]{2}|[A-Z]{2} [0-9]{2}|[A-Z]{3}[0-9]{4}|[A-Z]{3}[0-9]{2}|[A-Z]{3} [0-9]{2}')
     , ('MH', 'Marshall Islands', '((969)[6-7][0-9])(-\d{4})?')
     , ('MQ', 'Martinique', '.{1,255}')
     , ('MR', 'Mauritania', '.{1,255}')
     , ('MU', 'Mauritius', '([0-9A-R]\d{4})')
     , ('YT', 'Mayotte', '.{1,255}')
     , ('MX', 'Mexico', '\d{5}')
     , ('FM', 'Micronesia', '9694\d{1}(-\d{4})?')
     , ('MD', 'Moldova', '(MD[\-]?)?(\d{4})')
     , ('MC', 'Monaco', '.{1,255}')
     , ('MN', 'Mongolia', '\d{5}')
     , ('ME', 'Montenegro', '\d{5}')
     , ('MS', 'Montserrat', 'MSR\d{4}')
     , ('MA', 'Morocco', '[1-9]\d{4}')
     , ('MZ', 'Mozambique', '\d{4}')
     , ('MM', 'Myanmar', '\d{5}')
     , ('NA', 'Namibia', '\d{5}')
     , ('NR', 'Nauru', '(NRU68)')
     , ('NP', 'Nepal', '\d{5}')
     , ('NL', 'Netherlands', '[1-9]\d{3} [A-Z]{2}|[1-9]\d{3}[A-Z]{2}')
     , ('NC', 'New Caledonia', '988\d{2}')
     , ('NZ', 'New Zealand', '\d{4}')
     , ('NI', 'Nicaragua', '\d{5}')
     , ('NE', 'Niger', '\d{4}')
     , ('NG', 'Nigeria', '[1-9]\d{5}')
     , ('NU', 'Niue', '(9974)')
     , ('NF', 'Norfolk Island', '(2899)')
     , ('MP', 'Northern Mariana Islands', '9695\d{1}(-\d{4})?')
     , ('KP', 'North Korea', '.{1,255}')
     , ('NO', 'Norway', '\d{4}')
     , ('OM', 'Oman', '\d{3}')
     , ('PK', 'Pakistan', '[1-9]\d{4}')
     , ('PS', 'Palestinian Territory', '(P[1-9]\d{6})|(\d{3}-\d{3})')
     , ('PA', 'Panama', '\d{4}')
     , ('PG', 'Papua New Guinea', '\d{3}')
     , ('PY', 'Paraguay', '\d{4}')
     , ('PE', 'Peru', '\d{5}')
     , ('PH', 'Philippines', '\d{4}')
     , ('PN', 'Pitcairn', '(PCR9 1ZZ)')
     , ('PL', 'Poland', '[0-9]{2}[-]([0-9]){3}')
     , ('PT', 'Portugal', '[1-9]\d{3}((-)\d{3})')
     , ('PR', 'Puerto Rico', '.{1,255}')
     , ('QA', 'Qatar', '.{1,255}')
     , ('RE', 'Reunion', '.{1,255}')
     , ('RO', 'Romania', '\d{6}')
     , ('RU', 'Russia', '\d{6}')
     , ('RW', 'Rwanda', '.{1,255}')
     , ('BL', 'Saint Barthélemy', '.{1,255}')
     , ('SH', 'Saint Helena', '(ASCN 1ZZ|TDCU 1ZZ|STHL 1ZZ)')
     , ('KN', 'Saint Kitts and Nevis', 'KN\d{4}(\-\d{4})?')
     , ('LC', 'Saint Lucia', 'LC\d{2}  \d{3}')
     , ('MF', 'Saint Martin (French part)', '.{1,255}')
     , ('SX', 'Saint Martin (Dutch part)', '.{1,255}')
     , ('PM', 'Saint Pierre and Miquelon', '.{1,255}')
     , ('VC', 'Saint Vincent and the Grenadines', '(VC)(\d{4})')
     , ('SM', 'San Marino', '(4789\d)')
     , ('ST', 'São Tomé and Príncipe', '.{1,255}')
     , ('SA', 'Saudi Arabia', '[1-8]\d{4}([\-]\d{4})?')
     , ('SN', 'Senegal', '[1-8]\d{4}')
     , ('RS', 'Serbia', '\d{5,6}')
     , ('SC', 'Seychelles', '.{1,255}')
     , ('SL', 'Sierra Leone', '.{1,255}')
     , ('SG', 'Singapore', '\d{6}')
     , ('SK', 'Slovakia', '(\d{3} \d{2})|\d{5}')
     , ('SI', 'Slovenia', '[1-9]\d{3}')
     , ('SB', 'Solomon Islands', '.{1,255}')
     , ('SO', 'Somalia', '.{1,255}')
     , ('ZA', 'South Africa', '\d{4}')
     , ('GS', 'South Georgia/Sandwich Islands', '(SIQQ 1ZZ)')
     , ('KR', 'South Korea', '\d{5}')
     , ('SS', 'South Sudan', '\d{5}')
     , ('ES', 'Spain', '\d{5}')
     , ('LK', 'Sri Lanka', '\d{5}')
     , ('SD', 'Sudan', '\d{5}')
     , ('SR', 'Suriname', '.{1,255}')
     , ('SJ', 'Svalbard and Jan Mayen', '.{1,255}')
     , ('SZ', 'Eswatini', '([A-Z]\d{3})')
     , ('SE', 'Sweden', '[1-9]\d{2} \d{2}')
     , ('CH', 'Switzerland', '[1-9]\d{3}')
     , ('SY', 'Syria', '.{1,255}')
     , ('TW', 'Taiwan', '(\d{3}\-\d{3})|(\d{3}[-]\d{2})|(\d{6})|(\d{3})')
     , ('TJ', 'Tajikistan', '7\d{5}')
     , ('TZ', 'Tanzania', '\d{5}')
     , ('TH', 'Thailand', '\d{5}')
     , ('TL', 'Timor-Leste', '.{1,255}')
     , ('TG', 'Togo', '.{1,255}')
     , ('TK', 'Tokelau', '.{1,255}')
     , ('TO', 'Tonga', '.{1,255}')
     , ('TT', 'Trinidad and Tobago', '\d{6}')
     , ('TN', 'Tunisia', '\d{4}')
     , ('TR', 'Turkey', '\d{5}')
     , ('TM', 'Turkmenistan', '7\d{5}')
     , ('TC', 'Turks and Caicos Islands', '(TKCA 1ZZ)')
     , ('TV', 'Tuvalu', '.{1,255}')
     , ('UG', 'Uganda', '.{1,255}')
     , ('UA', 'Ukraine', '\d{5}')
     , ('AE', 'United Arab Emirates', '.{1,255}')
     , ('GB', 'United Kingdom (UK)', '([G][I][R] 0[A]{2})|((([A-Z][0-9]{1,2})|(([A-Z][A-HJ-Y][0-9]{1,2})|(([A-Z][0-9][A-Z])|([A-Z][A-HJ-Y][0-9]?[A-Z])))) [0-9][A-Z]{2})')
     , ('US', 'United States (US)', '\d{5}(-\d{4})?')
     , ('UM', 'United States (US) Minor Outlying Islands', '.{1,255}')
     , ('UY', 'Uruguay', '[1-9]\d{4}')
     , ('UZ', 'Uzbekistan', '\d{6}')
     , ('VU', 'Vanuatu', '.{1,255}')
     , ('VA', 'Vatican', '(00120)')
     , ('VE', 'Venezuela', '[1-8]\d{3}')
     , ('VN', 'Vietnam', '\d{6}')
     , ('VG', 'Virgin Islands (British)', '(VG11)[0-6][0]')
     , ('VI', 'Virgin Islands (US)', '008\d{2}(-\d{4})?')
     , ('WF', 'Wallis and Futuna', '(986)\d{2}')
     , ('EH', 'Western Sahara', '.{1,255}')
     , ('WS', 'Samoa', 'WS[1-2]\d{3}')
     , ('YE', 'Yemen', '.{1,255}')
     , ('ZM', 'Zambia', '\d{5}')
     , ('ZW', 'Zimbabwe', '.{1,255}')
;

-- Translations from WooCommerce
insert into camper.country_i18n
(country_code, lang_tag, name)
values ('AD', 'ca', 'Andorra')
     , ('AD', 'es', 'Andorra')
     , ('AD', 'fr', 'Andorre')
     , ('AE', 'ca', 'Emirats Àrabs Units')
     , ('AE', 'es', 'Emiratos Árabes Unidos')
     , ('AE', 'fr', 'Émirats Arabes Unis')
     , ('AF', 'ca', 'Afganistan')
     , ('AF', 'es', 'Afganistán')
     , ('AF', 'fr', 'Afghanistan')
     , ('AG', 'ca', 'Antigua i Barbuda')
     , ('AG', 'es', 'Antigua y Barbuda')
     , ('AG', 'fr', 'Antigua-et-Barbuda')
     , ('AI', 'ca', 'Anguilla')
     , ('AI', 'es', 'Anguilla')
     , ('AI', 'fr', 'Anguilla')
     , ('AL', 'ca', 'Albània')
     , ('AL', 'es', 'Albania')
     , ('AL', 'fr', 'Albanie')
     , ('AM', 'ca', 'Armènia')
     , ('AM', 'es', 'Armenia')
     , ('AM', 'fr', 'Arménie')
     , ('AO', 'ca', 'Angola')
     , ('AO', 'es', 'Angola')
     , ('AO', 'fr', 'Angola')
     , ('AQ', 'ca', 'Antàrtida')
     , ('AQ', 'es', 'Antártida')
     , ('AQ', 'fr', 'Antarctique')
     , ('AR', 'ca', 'Argentina')
     , ('AR', 'es', 'Argentina')
     , ('AR', 'fr', 'Argentine')
     , ('AS', 'ca', 'Samoa Nord-americana')
     , ('AS', 'es', 'Samoa Americana')
     , ('AS', 'fr', 'American Samoa')
     , ('AT', 'ca', 'Àustria')
     , ('AT', 'es', 'Austria')
     , ('AT', 'fr', 'Autriche')
     , ('AU', 'ca', 'Austràlia')
     , ('AU', 'es', 'Australia')
     , ('AU', 'fr', 'Australie')
     , ('AW', 'ca', 'Aruba')
     , ('AW', 'es', 'Aruba')
     , ('AW', 'fr', 'Aruba')
     , ('AX', 'ca', 'Illes Åland')
     , ('AX', 'es', 'Islas Åland')
     , ('AX', 'fr', 'Åland Islands')
     , ('AZ', 'ca', 'Azerbaidjan')
     , ('AZ', 'es', 'Azerbaijan')
     , ('AZ', 'fr', 'Azerbaijan')
     , ('BA', 'ca', 'Bòsnia i Hercegovina')
     , ('BA', 'es', 'Bosnia y Herzegovina')
     , ('BA', 'fr', 'Bosnie-Herzégovine')
     , ('BB', 'ca', 'Barbados')
     , ('BB', 'es', 'Barbados')
     , ('BB', 'fr', 'Barbades')
     , ('BD', 'ca', 'Bangladesh')
     , ('BD', 'es', 'Bangladesh')
     , ('BD', 'fr', 'Bangladesh')
     , ('BE', 'ca', 'Bèlgica')
     , ('BE', 'es', 'Bélgica')
     , ('BE', 'fr', 'Belgique')
     , ('BF', 'ca', 'Burkina Fasso')
     , ('BF', 'es', 'Burkina Faso')
     , ('BF', 'fr', 'Burkina Faso')
     , ('BG', 'ca', 'Bulgària')
     , ('BG', 'es', 'Bulgaria')
     , ('BG', 'fr', 'Bulgarie')
     , ('BH', 'ca', 'Bahrain')
     , ('BH', 'es', 'Bahrain')
     , ('BH', 'fr', 'Bahrain')
     , ('BI', 'ca', 'Burundi')
     , ('BI', 'es', 'Burundi')
     , ('BI', 'fr', 'Burundi')
     , ('BJ', 'ca', 'Benín')
     , ('BJ', 'es', 'Benin')
     , ('BJ', 'fr', 'Benin')
     , ('BL', 'ca', 'Saint-Barthélemy')
     , ('BL', 'es', 'San Bartolomé')
     , ('BL', 'fr', 'Saint Barthélemy')
     , ('BM', 'ca', 'Bermuda')
     , ('BM', 'es', 'Bermuda')
     , ('BM', 'fr', 'Bermudes')
     , ('BN', 'ca', 'Brunei')
     , ('BN', 'es', 'Brunéi')
     , ('BN', 'fr', 'Brunei')
     , ('BO', 'ca', 'Bolívia')
     , ('BO', 'es', 'Bolivia')
     , ('BO', 'fr', 'Bolivie')
     , ('BQ', 'ca', 'Bonaire, Saint Eustatius and Saba')
     , ('BQ', 'es', 'Bonaire, San Eustaquio y Saba')
     , ('BQ', 'fr', 'Saba, Saint-Eustache et Bonaire')
     , ('BR', 'ca', 'Brasil')
     , ('BR', 'es', 'Brasil')
     , ('BR', 'fr', 'Brésil')
     , ('BS', 'ca', 'Bahames')
     , ('BS', 'es', 'Bahamas')
     , ('BS', 'fr', 'Bahamas')
     , ('BT', 'ca', 'Bhutan')
     , ('BT', 'es', 'Bhutan')
     , ('BT', 'fr', 'Bhutan')
     , ('BV', 'ca', 'Illa Bouvet')
     , ('BV', 'es', 'Isla Bouvet')
     , ('BV', 'fr', 'Île Bouvet')
     , ('BW', 'ca', 'Botswana')
     , ('BW', 'es', 'Botswana')
     , ('BW', 'fr', 'Botswana')
     , ('BY', 'ca', 'Bielorússia')
     , ('BY', 'es', 'Bielorrusia')
     , ('BY', 'fr', 'Biélorussie')
     , ('BZ', 'ca', 'Belize')
     , ('BZ', 'es', 'Belize')
     , ('BZ', 'fr', 'Belize')
     , ('CA', 'ca', 'Canadà')
     , ('CA', 'es', 'Canadá')
     , ('CA', 'fr', 'Canada')
     , ('CC', 'ca', 'Illes Cocos (Keeling)')
     , ('CC', 'es', 'Islas Cocos')
     , ('CC', 'fr', 'Îles Cocos')
     , ('CD', 'ca', 'Congo (Kinshasa)')
     , ('CD', 'es', 'Congo (Kinshasa)')
     , ('CD', 'fr', 'Congo (Kinshasa)')
     , ('CF', 'ca', 'República Centreafricana')
     , ('CF', 'es', 'República Centroafricana')
     , ('CF', 'fr', 'République Centrafricaine')
     , ('CG', 'ca', 'Congo (Brazzaville)')
     , ('CG', 'es', 'Congo (Brazzaville)')
     , ('CG', 'fr', 'Congo (Brazzaville)')
     , ('CH', 'ca', 'Suïssa')
     , ('CH', 'es', 'Suiza')
     , ('CH', 'fr', 'Suisse')
     , ('CI', 'ca', 'Costa d’Ivori')
     , ('CI', 'es', 'Costa de Marfil')
     , ('CI', 'fr', 'Côte-d’Ivoire')
     , ('CK', 'ca', 'Illes Cook')
     , ('CK', 'es', 'Islas Cook')
     , ('CK', 'fr', 'Îles Cook')
     , ('CL', 'ca', 'Xile')
     , ('CL', 'es', 'Chile')
     , ('CL', 'fr', 'Chili')
     , ('CM', 'ca', 'Camerun')
     , ('CM', 'es', 'Camerún')
     , ('CM', 'fr', 'Cameroun')
     , ('CN', 'ca', 'Xina')
     , ('CN', 'es', 'China')
     , ('CN', 'fr', 'Chine')
     , ('CO', 'ca', 'Colòmbia')
     , ('CO', 'es', 'Colombia')
     , ('CO', 'fr', 'Colombie')
     , ('CR', 'ca', 'Costa Rica')
     , ('CR', 'es', 'Costa Rica')
     , ('CR', 'fr', 'Costa Rica')
     , ('CU', 'ca', 'Cuba')
     , ('CU', 'es', 'Cuba')
     , ('CU', 'fr', 'Cuba')
     , ('CV', 'ca', 'Cap Verd')
     , ('CV', 'es', 'Cabo Verde')
     , ('CV', 'fr', 'Cap Vert')
     , ('CW', 'ca', 'Curaçao')
     , ('CW', 'es', 'Curaçao')
     , ('CW', 'fr', 'Curaçao')
     , ('CX', 'ca', 'Illa Christmas')
     , ('CX', 'es', 'Isla de Navidad')
     , ('CX', 'fr', 'Christmas Island')
     , ('CY', 'ca', 'Xipre')
     , ('CY', 'es', 'Chipre')
     , ('CY', 'fr', 'Chypre')
     , ('CZ', 'ca', 'República Txeca')
     , ('CZ', 'es', 'República Checa')
     , ('CZ', 'fr', 'République Tchèque')
     , ('DE', 'ca', 'Alemanya')
     , ('DE', 'es', 'Alemania')
     , ('DE', 'fr', 'Allemagne')
     , ('DJ', 'ca', 'Djibouti')
     , ('DJ', 'es', 'Djibouti')
     , ('DJ', 'fr', 'Djibouti')
     , ('DK', 'ca', 'Dinamarca')
     , ('DK', 'es', 'Dinamarca')
     , ('DK', 'fr', 'Danemark')
     , ('DM', 'ca', 'Dominica')
     , ('DM', 'es', 'Dominica')
     , ('DM', 'fr', 'Dominique')
     , ('DO', 'ca', 'República Dominicana')
     , ('DO', 'es', 'República Dominicana')
     , ('DO', 'fr', 'République Dominicaine')
     , ('DZ', 'ca', 'Algèria')
     , ('DZ', 'es', 'Argelia')
     , ('DZ', 'fr', 'Algérie')
     , ('EC', 'ca', 'Equador')
     , ('EC', 'es', 'Ecuador')
     , ('EC', 'fr', 'Équateur')
     , ('EE', 'ca', 'Estònia')
     , ('EE', 'es', 'Estonia')
     , ('EE', 'fr', 'Estonie')
     , ('EG', 'ca', 'Egipte')
     , ('EG', 'es', 'Egipto')
     , ('EG', 'fr', 'Égypte')
     , ('EH', 'ca', 'Sàhara Occidental')
     , ('EH', 'es', 'Sahara Occidental')
     , ('EH', 'fr', 'Sahara occidental')
     , ('ER', 'ca', 'Eritrea')
     , ('ER', 'es', 'Eritrea')
     , ('ER', 'fr', 'Erythrée')
     , ('ES', 'ca', 'Espanya')
     , ('ES', 'es', 'España')
     , ('ES', 'fr', 'Espagne')
     , ('ET', 'ca', 'Etiòpia')
     , ('ET', 'es', 'Etiopía')
     , ('ET', 'fr', 'Éthiopie')
     , ('FI', 'ca', 'Finlàndia')
     , ('FI', 'es', 'Finlandia')
     , ('FI', 'fr', 'Finlande')
     , ('FJ', 'ca', 'Fiji')
     , ('FJ', 'es', 'Fiyi')
     , ('FJ', 'fr', 'Fidji')
     , ('FK', 'ca', 'Illes Falkland')
     , ('FK', 'es', 'Islas Malvinas')
     , ('FK', 'fr', 'Îles Falkland')
     , ('FM', 'ca', 'Micronèsia')
     , ('FM', 'es', 'Micronesia')
     , ('FM', 'fr', 'Micronésie')
     , ('FO', 'ca', 'Illes Faroe')
     , ('FO', 'es', 'Islas Feroe')
     , ('FO', 'fr', 'Îles Féroé')
     , ('FR', 'ca', 'França')
     , ('FR', 'es', 'Francia')
     , ('FR', 'fr', 'France')
     , ('GA', 'ca', 'Gabon')
     , ('GA', 'es', 'Gabón')
     , ('GA', 'fr', 'Gabon')
     , ('GB', 'ca', 'Regne Unit (UK)')
     , ('GB', 'es', 'Reino Unido (UK)')
     , ('GB', 'fr', 'Royaume-Uni (UK)')
     , ('GD', 'ca', 'Grenada')
     , ('GD', 'es', 'Granada')
     , ('GD', 'fr', 'Grenade')
     , ('GE', 'ca', 'Geòrgia')
     , ('GE', 'es', 'Georgia')
     , ('GE', 'fr', 'Géorgie')
     , ('GF', 'ca', 'Guaiana Francesa')
     , ('GF', 'es', 'Guayana Francesa')
     , ('GF', 'fr', 'Guyane Française')
     , ('GG', 'ca', 'Guernsey')
     , ('GG', 'es', 'Guernsey')
     , ('GG', 'fr', 'Guernesey')
     , ('GH', 'ca', 'Ghana')
     , ('GH', 'es', 'Ghana')
     , ('GH', 'fr', 'Ghana')
     , ('GI', 'ca', 'Gibraltar')
     , ('GI', 'es', 'Gibraltar')
     , ('GI', 'fr', 'Gibraltar')
     , ('GL', 'ca', 'Groenlàndia')
     , ('GL', 'es', 'Groenlandia')
     , ('GL', 'fr', 'Groenland')
     , ('GM', 'ca', 'Gàmbia')
     , ('GM', 'es', 'Gambia')
     , ('GM', 'fr', 'Gambie')
     , ('GN', 'ca', 'Guinea')
     , ('GN', 'es', 'Guinea')
     , ('GN', 'fr', 'Guinée')
     , ('GP', 'ca', 'Guadalupe')
     , ('GP', 'es', 'Guadalupe')
     , ('GP', 'fr', 'Guadeloupe')
     , ('GQ', 'ca', 'Guinea Equatorial')
     , ('GQ', 'es', 'Guinea Ecuatorial')
     , ('GQ', 'fr', 'Guinée équatoriale')
     , ('GR', 'ca', 'Grècia')
     , ('GR', 'es', 'Grecia')
     , ('GR', 'fr', 'Grèce')
     , ('GS', 'ca', 'Illes Geòrgia del Sud i Sandwich del Sud')
     , ('GS', 'es', 'Islas Georgias y Sandwich del Sur')
     , ('GS', 'fr', 'Géorgie du Sud / îles Sandwich')
     , ('GT', 'ca', 'Guatemala')
     , ('GT', 'es', 'Guatemala')
     , ('GT', 'fr', 'Guatemala')
     , ('GU', 'ca', 'Guam')
     , ('GU', 'es', 'Guam')
     , ('GU', 'fr', 'Guam')
     , ('GW', 'ca', 'Guinea Bissau')
     , ('GW', 'es', 'Guinea-Bisáu')
     , ('GW', 'fr', 'Guinée-Bissau')
     , ('GY', 'ca', 'Guyana')
     , ('GY', 'es', 'Guyana')
     , ('GY', 'fr', 'Guyane')
     , ('HK', 'ca', 'Hong Kong')
     , ('HK', 'es', 'Hong Kong')
     , ('HK', 'fr', 'Hong Kong')
     , ('HM', 'ca', 'Illes Heard i McDonald')
     , ('HM', 'es', 'Islas Heard y McDonald')
     , ('HM', 'fr', 'Îles Heard-et-MacDonald')
     , ('HN', 'ca', 'Hondures')
     , ('HN', 'es', 'Honduras')
     , ('HN', 'fr', 'Honduras')
     , ('HR', 'ca', 'Croàcia')
     , ('HR', 'es', 'Croacia')
     , ('HR', 'fr', 'Croatie')
     , ('HT', 'ca', 'Haití')
     , ('HT', 'es', 'Haití')
     , ('HT', 'fr', 'Haïti')
     , ('HU', 'ca', 'Hongria')
     , ('HU', 'es', 'Hungría')
     , ('HU', 'fr', 'Hongrie')
     , ('ID', 'ca', 'Indonèsia')
     , ('ID', 'es', 'Indonesia')
     , ('ID', 'fr', 'Indonésie')
     , ('IE', 'ca', 'Irlanda')
     , ('IE', 'es', 'Irlanda')
     , ('IE', 'fr', 'Irlande')
     , ('IL', 'ca', 'Israel')
     , ('IL', 'es', 'Israel')
     , ('IL', 'fr', 'Israël')
     , ('IM', 'ca', 'Illa de Man')
     , ('IM', 'es', 'Isla de Man')
     , ('IM', 'fr', 'Île de Man')
     , ('IN', 'ca', 'Índia')
     , ('IN', 'es', 'India')
     , ('IN', 'fr', 'Inde')
     , ('IO', 'ca', 'Territori Britànic de l’Oceà Índic')
     , ('IO', 'es', 'Territorio Británico del Océano Índico')
     , ('IO', 'fr', 'Territoire britannique de l’océan Indien')
     , ('IQ', 'ca', 'Iraq')
     , ('IQ', 'es', 'Irak')
     , ('IQ', 'fr', 'Iraq')
     , ('IR', 'ca', 'Iran')
     , ('IR', 'es', 'Irán')
     , ('IR', 'fr', 'Iran')
     , ('IS', 'ca', 'Islàndia')
     , ('IS', 'es', 'Islandia')
     , ('IS', 'fr', 'Islande')
     , ('IT', 'ca', 'Itàlia')
     , ('IT', 'es', 'Italia')
     , ('IT', 'fr', 'Italie')
     , ('JE', 'ca', 'Jersey')
     , ('JE', 'es', 'Jersey')
     , ('JE', 'fr', 'Jersey')
     , ('JM', 'ca', 'Jamaica')
     , ('JM', 'es', 'Jamaica')
     , ('JM', 'fr', 'Jamaïque')
     , ('JO', 'ca', 'Jordània')
     , ('JO', 'es', 'Jordania')
     , ('JO', 'fr', 'Jordanie')
     , ('JP', 'ca', 'Japó')
     , ('JP', 'es', 'Japón')
     , ('JP', 'fr', 'Japon')
     , ('KE', 'ca', 'Kenya')
     , ('KE', 'es', 'Kenia')
     , ('KE', 'fr', 'Kenya')
     , ('KG', 'ca', 'Kirguizistan')
     , ('KG', 'es', 'Kirguistán')
     , ('KG', 'fr', 'Kyrgyzstan')
     , ('KH', 'ca', 'Cambodja')
     , ('KH', 'es', 'Camboya')
     , ('KH', 'fr', 'Cambodge')
     , ('KI', 'ca', 'Kiribati')
     , ('KI', 'es', 'Kiribati')
     , ('KI', 'fr', 'Kiribati')
     , ('KM', 'ca', 'Comores')
     , ('KM', 'es', 'Comoras')
     , ('KM', 'fr', 'Comores')
     , ('KN', 'ca', 'Saint Kitts i Nevis')
     , ('KN', 'es', 'San Cristóbal y Nieves')
     , ('KN', 'fr', 'Saint-Kitts-et-Nevis')
     , ('KP', 'ca', 'Corea del Nord')
     , ('KP', 'es', 'Corea del Norte')
     , ('KP', 'fr', 'Corée du Nord')
     , ('KR', 'ca', 'Corea del Sud')
     , ('KR', 'es', 'Corea del Sur')
     , ('KR', 'fr', 'Corée du Sud')
     , ('KW', 'ca', 'Kuwait')
     , ('KW', 'es', 'Kuwait')
     , ('KW', 'fr', 'Koweït')
     , ('KY', 'ca', 'Illes Caiman')
     , ('KY', 'es', 'Islas Caimán')
     , ('KY', 'fr', 'Îles Caïmans')
     , ('KZ', 'ca', 'Kazakhstan')
     , ('KZ', 'es', 'Kazajistán')
     , ('KZ', 'fr', 'Kazakhstan')
     , ('LA', 'ca', 'Laos')
     , ('LA', 'es', 'Laos')
     , ('LA', 'fr', 'Laos')
     , ('LB', 'ca', 'Líban')
     , ('LB', 'es', 'Líbano')
     , ('LB', 'fr', 'Liban')
     , ('LC', 'ca', 'Saint Lucia')
     , ('LC', 'es', 'Santa Lucía')
     , ('LC', 'fr', 'Sainte-Lucie')
     , ('LI', 'ca', 'Liechtenstein')
     , ('LI', 'es', 'Liechtenstein')
     , ('LI', 'fr', 'Liechtenstein')
     , ('LK', 'ca', 'Sri Lanka')
     , ('LK', 'es', 'Sri Lanka')
     , ('LK', 'fr', 'Sri Lanka')
     , ('LR', 'ca', 'Libèria')
     , ('LR', 'es', 'Liberia')
     , ('LR', 'fr', 'Liberia')
     , ('LS', 'ca', 'Lesotho')
     , ('LS', 'es', 'Lesoto')
     , ('LS', 'fr', 'Lesotho')
     , ('LT', 'ca', 'Lituània')
     , ('LT', 'es', 'Lituania')
     , ('LT', 'fr', 'Lituanie')
     , ('LU', 'ca', 'Luxemburg')
     , ('LU', 'es', 'Luxemburgo')
     , ('LU', 'fr', 'Luxembourg')
     , ('LV', 'ca', 'Letònia')
     , ('LV', 'es', 'Letonia')
     , ('LV', 'fr', 'Lettonie')
     , ('LY', 'ca', 'Líbia')
     , ('LY', 'es', 'Libia')
     , ('LY', 'fr', 'Libye')
     , ('MA', 'ca', 'Marroc')
     , ('MA', 'es', 'Marruecos')
     , ('MA', 'fr', 'Maroc')
     , ('MC', 'ca', 'Mònaco')
     , ('MC', 'es', 'Mónaco')
     , ('MC', 'fr', 'Monaco')
     , ('MD', 'ca', 'Moldàvia')
     , ('MD', 'es', 'Moldavia')
     , ('MD', 'fr', 'Moldavie')
     , ('ME', 'ca', 'Montenegro')
     , ('ME', 'es', 'Montenegro')
     , ('ME', 'fr', 'Montenegro')
     , ('MF', 'ca', 'Saint Martin (part francesa)')
     , ('MF', 'es', 'San Martín (parte de Francia)')
     , ('MF', 'fr', 'Saint-Martin (partie française)')
     , ('MG', 'ca', 'Madagascar')
     , ('MG', 'es', 'Madagascar')
     , ('MG', 'fr', 'Madagascar')
     , ('MH', 'ca', 'Illes Marshall')
     , ('MH', 'es', 'Islas Marshall')
     , ('MH', 'fr', 'Îles Marshall')
     , ('MK', 'ca', 'Macedònia del Nord')
     , ('MK', 'es', 'Macedonia del Norte')
     , ('MK', 'fr', 'Macédoine du Nord')
     , ('ML', 'ca', 'Mali')
     , ('ML', 'es', 'Malí')
     , ('ML', 'fr', 'Mali')
     , ('MM', 'ca', 'Myanmar')
     , ('MM', 'es', 'Birmania')
     , ('MM', 'fr', 'Myanmar')
     , ('MN', 'ca', 'Mongòlia')
     , ('MN', 'es', 'Mongolia')
     , ('MN', 'fr', 'Mongolie')
     , ('MO', 'ca', 'Macau')
     , ('MO', 'es', 'Macao')
     , ('MO', 'fr', 'Macao')
     , ('MP', 'ca', 'Illes Mariannes Septentrionals')
     , ('MP', 'es', 'Islas Marianas del Norte')
     , ('MP', 'fr', 'Northern Mariana Islands')
     , ('MQ', 'ca', 'Martinica')
     , ('MQ', 'es', 'Martinica')
     , ('MQ', 'fr', 'Martinique')
     , ('MR', 'ca', 'Mauritània')
     , ('MR', 'es', 'Mauritania')
     , ('MR', 'fr', 'Mauritanie')
     , ('MS', 'ca', 'Montserrat')
     , ('MS', 'es', 'Montserrat')
     , ('MS', 'fr', 'Montserrat')
     , ('MT', 'ca', 'Malta')
     , ('MT', 'es', 'Malta')
     , ('MT', 'fr', 'Malte')
     , ('MU', 'ca', 'Maurici')
     , ('MU', 'es', 'Mauricio')
     , ('MU', 'fr', 'Maurice')
     , ('MV', 'ca', 'Maldives')
     , ('MV', 'es', 'Maldivas')
     , ('MV', 'fr', 'Maldives')
     , ('MW', 'ca', 'Malawi')
     , ('MW', 'es', 'Malaui')
     , ('MW', 'fr', 'Malawi')
     , ('MX', 'ca', 'Mèxic')
     , ('MX', 'es', 'México')
     , ('MX', 'fr', 'Mexique')
     , ('MY', 'ca', 'Malàisia')
     , ('MY', 'es', 'Malasia')
     , ('MY', 'fr', 'Malaisie')
     , ('MZ', 'ca', 'Moçambic')
     , ('MZ', 'es', 'Mozambique')
     , ('MZ', 'fr', 'Mozambique')
     , ('NA', 'ca', 'Namíbia')
     , ('NA', 'es', 'Namibia')
     , ('NA', 'fr', 'Namibie')
     , ('NC', 'ca', 'Nova Caledònia')
     , ('NC', 'es', 'Nueva Caledonia')
     , ('NC', 'fr', 'Nouvelle-Calédonie')
     , ('NE', 'ca', 'Níger')
     , ('NE', 'es', 'Níger')
     , ('NE', 'fr', 'Niger')
     , ('NF', 'ca', 'Illa Norfolk')
     , ('NF', 'es', 'Isla Norfolk')
     , ('NF', 'fr', 'Île Norfolk')
     , ('NG', 'ca', 'Nigèria')
     , ('NG', 'es', 'Nigeria')
     , ('NG', 'fr', 'Nigeria')
     , ('NI', 'ca', 'Nicaragua')
     , ('NI', 'es', 'Nicaragua')
     , ('NI', 'fr', 'Nicaragua')
     , ('NL', 'ca', 'Països Baixos')
     , ('NL', 'es', 'Países Bajos')
     , ('NL', 'fr', 'Pays-Bas')
     , ('NO', 'ca', 'Noruega')
     , ('NO', 'es', 'Noruega')
     , ('NO', 'fr', 'Norvège')
     , ('NP', 'ca', 'Nepal')
     , ('NP', 'es', 'Nepal')
     , ('NP', 'fr', 'Népal')
     , ('NR', 'ca', 'Nauru')
     , ('NR', 'es', 'Nauru')
     , ('NR', 'fr', 'Nauru')
     , ('NU', 'ca', 'Niue')
     , ('NU', 'es', 'Niue')
     , ('NU', 'fr', 'Niue')
     , ('NZ', 'ca', 'Nova Zelanda')
     , ('NZ', 'es', 'Nueva Zelanda')
     , ('NZ', 'fr', 'Nouvelle-Zélande')
     , ('OM', 'ca', 'Oman')
     , ('OM', 'es', 'Omán')
     , ('OM', 'fr', 'Oman')
     , ('PA', 'ca', 'Panamà')
     , ('PA', 'es', 'Panamá')
     , ('PA', 'fr', 'Panama')
     , ('PE', 'ca', 'Perú')
     , ('PE', 'es', 'Perú')
     , ('PE', 'fr', 'Pérou')
     , ('PF', 'ca', 'Polinèsia Francesa')
     , ('PF', 'es', 'Polinesia Francesa')
     , ('PF', 'fr', 'Polynésie Française')
     , ('PG', 'ca', 'Papua Nova Guinea')
     , ('PG', 'es', 'Papúa Nueva Guinea')
     , ('PG', 'fr', 'Papouasie-Nouvelle-Guinée')
     , ('PH', 'ca', 'Filipines')
     , ('PH', 'es', 'Filipinas')
     , ('PH', 'fr', 'Philippines')
     , ('PK', 'ca', 'Pakistan')
     , ('PK', 'es', 'Pakistán')
     , ('PK', 'fr', 'Pakistan')
     , ('PL', 'ca', 'Polònia')
     , ('PL', 'es', 'Polonia')
     , ('PL', 'fr', 'Pologne')
     , ('PM', 'ca', 'Saint-Pierre i Miquelon')
     , ('PM', 'es', 'San Pedro y Miquelón')
     , ('PM', 'fr', 'Saint Pierre et Miquelon')
     , ('PN', 'ca', 'Pitcairn')
     , ('PN', 'es', 'Pitcairn')
     , ('PN', 'fr', 'Pitcairn')
     , ('PR', 'ca', 'Puerto Rico')
     , ('PR', 'es', 'Puerto Rico')
     , ('PR', 'fr', 'Puerto Rico')
     , ('PS', 'ca', 'Palestina')
     , ('PS', 'es', 'Territorios Palestinos')
     , ('PS', 'fr', 'Territoire Palestinien')
     , ('PT', 'ca', 'Portugal')
     , ('PT', 'es', 'Portugal')
     , ('PT', 'fr', 'Portugal')
     , ('PW', 'ca', 'Belau')
     , ('PW', 'es', 'Belau')
     , ('PW', 'fr', 'Belau')
     , ('PY', 'ca', 'Paraguai')
     , ('PY', 'es', 'Paraguay')
     , ('PY', 'fr', 'Paraguay')
     , ('QA', 'ca', 'Qatar')
     , ('QA', 'es', 'Qatar')
     , ('QA', 'fr', 'Qatar')
     , ('RE', 'ca', 'Reunió')
     , ('RE', 'es', 'Reunión')
     , ('RE', 'fr', 'La Réunion')
     , ('RO', 'ca', 'Romania')
     , ('RO', 'es', 'Rumania')
     , ('RO', 'fr', 'Roumanie')
     , ('RS', 'ca', 'Sèrbia')
     , ('RS', 'es', 'Serbia')
     , ('RS', 'fr', 'Serbie')
     , ('RU', 'ca', 'Rússia')
     , ('RU', 'es', 'Rusia')
     , ('RU', 'fr', 'Russie')
     , ('RW', 'ca', 'Ruanda')
     , ('RW', 'es', 'Ruanda')
     , ('RW', 'fr', 'Rwanda')
     , ('SA', 'ca', 'Aràbia Saudita')
     , ('SA', 'es', 'Arabia Saudita')
     , ('SA', 'fr', 'Arabie Saoudite')
     , ('SB', 'ca', 'Illes Salomó')
     , ('SB', 'es', 'Islas Salomón')
     , ('SB', 'fr', 'Îles Salomon')
     , ('SC', 'ca', 'Seychelles')
     , ('SC', 'es', 'Seychelles')
     , ('SC', 'fr', 'Seychelles')
     , ('SD', 'ca', 'Sudan')
     , ('SD', 'es', 'Sudán')
     , ('SD', 'fr', 'Soudan')
     , ('SE', 'ca', 'Suècia')
     , ('SE', 'es', 'Suecia')
     , ('SE', 'fr', 'Suède')
     , ('SG', 'ca', 'Singapur')
     , ('SG', 'es', 'Singapur')
     , ('SG', 'fr', 'Singapour')
     , ('SH', 'ca', 'Saint Helena')
     , ('SH', 'es', 'Isla Santa Elena')
     , ('SH', 'fr', 'Sainte-Hélène')
     , ('SI', 'ca', 'Eslovènia')
     , ('SI', 'es', 'Eslovenia')
     , ('SI', 'fr', 'Slovénie')
     , ('SJ', 'ca', 'Svalbard i Jan Mayen')
     , ('SJ', 'es', 'Svalbard y Jan Mayen')
     , ('SJ', 'fr', 'Svalbard et Jan Mayen')
     , ('SK', 'ca', 'Eslovàquia')
     , ('SK', 'es', 'Eslovaquia')
     , ('SK', 'fr', 'Slovaquie')
     , ('SL', 'ca', 'Sierra Leone')
     , ('SL', 'es', 'Sierra Leona')
     , ('SL', 'fr', 'Sierra Leone')
     , ('SM', 'ca', 'San Marino')
     , ('SM', 'es', 'San Marino')
     , ('SM', 'fr', 'San Marino')
     , ('SN', 'ca', 'Senegal')
     , ('SN', 'es', 'Senegal')
     , ('SN', 'fr', 'Sénégal')
     , ('SO', 'ca', 'Somàlia')
     , ('SO', 'es', 'Somalia')
     , ('SO', 'fr', 'Somalie')
     , ('SR', 'ca', 'Surinam')
     , ('SR', 'es', 'Surinam')
     , ('SR', 'fr', 'Suriname')
     , ('SS', 'ca', 'Sudan del Sud')
     , ('SS', 'es', 'Sudán del Sur')
     , ('SS', 'fr', 'Soudan du Sud')
     , ('ST', 'ca', 'São Tomé i Príncipe')
     , ('ST', 'es', 'Santo Tomé y Príncipe')
     , ('ST', 'fr', 'Sao Tomé-et-Principe')
     , ('SV', 'ca', 'El Salvador')
     , ('SV', 'es', 'El Salvador')
     , ('SV', 'fr', 'Salvador')
     , ('SX', 'ca', 'Saint Martin (part holandesa)')
     , ('SX', 'es', 'San Martín (Países Bajos)')
     , ('SX', 'fr', 'Saint-Martin (partie néerlandaise)')
     , ('SY', 'ca', 'Síria')
     , ('SY', 'es', 'Siria')
     , ('SY', 'fr', 'Syrie')
     , ('SZ', 'ca', 'Eswatini')
     , ('SZ', 'es', 'Esuatini')
     , ('SZ', 'fr', 'Eswatini')
     , ('TC', 'ca', 'Illes Turks i Caicos')
     , ('TC', 'es', 'Islas Turcas y Caicos')
     , ('TC', 'fr', 'Îles Turques et Caïques')
     , ('TD', 'ca', 'Txad')
     , ('TD', 'es', 'Chad')
     , ('TD', 'fr', 'Tchad')
     , ('TF', 'ca', 'Terres Australs Franceses')
     , ('TF', 'es', 'Territorios australes franceses')
     , ('TF', 'fr', 'Terres Australes Françaises')
     , ('TG', 'ca', 'Togo')
     , ('TG', 'es', 'Togo')
     , ('TG', 'fr', 'Togo')
     , ('TH', 'ca', 'Tailàndia')
     , ('TH', 'es', 'Tailandia')
     , ('TH', 'fr', 'Thailande')
     , ('TJ', 'ca', 'Tadjikistan')
     , ('TJ', 'es', 'Tayikistán')
     , ('TJ', 'fr', 'Tajikistan')
     , ('TK', 'ca', 'Tokelau')
     , ('TK', 'es', 'Tokelau')
     , ('TK', 'fr', 'Tokelau')
     , ('TL', 'ca', 'Timor Oriental')
     , ('TL', 'es', 'Timor Oriental')
     , ('TL', 'fr', 'Timor-Leste')
     , ('TM', 'ca', 'Turkmenistan')
     , ('TM', 'es', 'Turkmenistán')
     , ('TM', 'fr', 'Turkménistan')
     , ('TN', 'ca', 'Tunísia')
     , ('TN', 'es', 'Túnez')
     , ('TN', 'fr', 'Tunisie')
     , ('TO', 'ca', 'Tonga')
     , ('TO', 'es', 'Tonga')
     , ('TO', 'fr', 'Tonga')
     , ('TR', 'ca', 'Turquia')
     , ('TR', 'es', 'Turquía')
     , ('TR', 'fr', 'Turquie')
     , ('TT', 'ca', 'Trinitat i Tobago')
     , ('TT', 'es', 'Trinidad y Tobago')
     , ('TT', 'fr', 'Trinité-et-Tobago')
     , ('TV', 'ca', 'Tuvalu')
     , ('TV', 'es', 'Tuvalu')
     , ('TV', 'fr', 'Tuvalu')
     , ('TW', 'ca', 'Taiwan')
     , ('TW', 'es', 'Taiwán')
     , ('TW', 'fr', 'Taiwan')
     , ('TZ', 'ca', 'Tanzània')
     , ('TZ', 'es', 'Tanzania')
     , ('TZ', 'fr', 'Tanzanie')
     , ('UA', 'ca', 'Ucraïna')
     , ('UA', 'es', 'Ucrania')
     , ('UA', 'fr', 'Ukraine')
     , ('UG', 'ca', 'Uganda')
     , ('UG', 'es', 'Uganda')
     , ('UG', 'fr', 'Uganda')
     , ('UM', 'ca', 'Illes d’Ultramar Menors dels Estats Units')
     , ('UM', 'es', 'Islas de ultramar menores de Estados Unidos (EEUU)')
     , ('UM', 'fr', 'Îles Mineures éloignées des États-Unis')
     , ('US', 'ca', 'Estats Units (US)')
     , ('US', 'es', 'Estados Unidos (EEUU)')
     , ('US', 'fr', 'Etats-Unis (USA)')
     , ('UY', 'ca', 'Uruguai')
     , ('UY', 'es', 'Uruguay')
     , ('UY', 'fr', 'Uruguay')
     , ('UZ', 'ca', 'Uzbekistan')
     , ('UZ', 'es', 'Uzbekistán')
     , ('UZ', 'fr', 'Uzbekistan')
     , ('VA', 'ca', 'Vaticà')
     , ('VA', 'es', 'Ciudad del Vaticano')
     , ('VA', 'fr', 'Vatican')
     , ('VC', 'ca', 'Saint Vincent i les Grenadines')
     , ('VC', 'es', 'San Vicente y las Granadinas')
     , ('VC', 'fr', 'Saint-Vincent-et-les-Grenadines')
     , ('VE', 'ca', 'Veneçuela')
     , ('VE', 'es', 'Venezuela')
     , ('VE', 'fr', 'Venezuela')
     , ('VG', 'ca', 'Illes Verges (Britàniques)')
     , ('VG', 'es', 'Islas Vírgenes (Británicas)')
     , ('VG', 'fr', 'Virgin Islands (British)')
     , ('VI', 'ca', 'Illes Verges (EUA)')
     , ('VI', 'es', 'Islas Vírgenes (EEUU)')
     , ('VI', 'fr', 'Virgin Islands (US)')
     , ('VN', 'ca', 'Vietnam')
     , ('VN', 'es', 'Vietnam')
     , ('VN', 'fr', 'Vietnam')
     , ('VU', 'ca', 'Vanuatu')
     , ('VU', 'es', 'Vanuatu')
     , ('VU', 'fr', 'Vanuatu')
     , ('WF', 'ca', 'Wallis i Futuna')
     , ('WF', 'es', 'Wallis y Futuna')
     , ('WF', 'fr', 'Wallis et Futuna')
     , ('WS', 'ca', 'Samoa')
     , ('WS', 'es', 'Samoa')
     , ('WS', 'fr', 'Samoa')
     , ('YE', 'ca', 'Iemen')
     , ('YE', 'es', 'Yemen')
     , ('YE', 'fr', 'Yemen')
     , ('YT', 'ca', 'Mayotte')
     , ('YT', 'es', 'Mayotte')
     , ('YT', 'fr', 'Mayotte')
     , ('ZA', 'ca', 'Sud-àfrica')
     , ('ZA', 'es', 'Sudáfrica')
     , ('ZA', 'fr', 'Afrique du Sud')
     , ('ZM', 'ca', 'Zàmbia')
     , ('ZM', 'es', 'Zambia')
     , ('ZM', 'fr', 'Zambie')
     , ('ZW', 'ca', 'Zimbàbue')
     , ('ZW', 'es', 'Zimbabue')
     , ('ZW', 'fr', 'Zimbabwe')
;

commit;
