-- Deploy camper:season to pg
-- requires: roles
-- requires: schema_camper
-- requires: company
-- requires: user_profile

begin;

set search_path to camper, public;

create table season (
	season_id integer generated by default as identity primary key,
	company_id integer not null references company,
	slug uuid not null unique default gen_random_uuid(),
	name text not null constraint name_not_empty check(length(trim(name)) > 0),
	color integer not null default 0,
	active boolean not null default true,
	position integer not null default 2147483647
);

grant select on table season to guest;
grant select on table season to employee;
grant select, insert, delete, update on table season to admin;

alter table season enable row level security;

create policy guest_ok
on season
for select
using (true)
;

create policy insert_to_company
on season
for insert
with check (
	company_id in (select company_id from user_profile)
)
;

create policy update_company
on season
for update
using (
	company_id in (select company_id from user_profile)
)
;

create policy delete_from_company
on season
for delete
using (
	company_id in (select company_id from user_profile)
)
;

commit;
