-- Test campsite_type_feature
set client_min_messages to warning;
create extension if not exists pgtap;
reset client_min_messages;

begin;

select plan(46);

set search_path to camper, public;

select has_table('campsite_type_feature');
select has_pk('campsite_type_feature');
select table_privs_are('campsite_type_feature', 'guest', array['SELECT']);
select table_privs_are('campsite_type_feature', 'employee', array['SELECT']);
select table_privs_are('campsite_type_feature', 'admin', array['SELECT', 'INSERT', 'UPDATE', 'DELETE']);
select table_privs_are('campsite_type_feature', 'authenticator', array[]::text[]);

select has_column('campsite_type_feature', 'campsite_type_feature_id');
select col_is_pk('campsite_type_feature', 'campsite_type_feature_id');
select col_type_is('campsite_type_feature', 'campsite_type_feature_id', 'integer');
select col_not_null('campsite_type_feature', 'campsite_type_feature_id');
select col_hasnt_default('campsite_type_feature', 'campsite_type_feature_id');

select has_column('campsite_type_feature', 'campsite_type_id');
select col_is_fk('campsite_type_feature', 'campsite_type_id');
select fk_ok('campsite_type_feature', 'campsite_type_id', 'campsite_type', 'campsite_type_id');
select col_type_is('campsite_type_feature', 'campsite_type_id', 'integer');
select col_not_null('campsite_type_feature', 'campsite_type_id');
select col_hasnt_default('campsite_type_feature', 'campsite_type_id');

select has_column('campsite_type_feature', 'icon_name');
select col_is_fk('campsite_type_feature', 'icon_name');
select fk_ok('campsite_type_feature', 'icon_name', 'icon', 'icon_name');
select col_type_is('campsite_type_feature', 'icon_name', 'text');
select col_not_null('campsite_type_feature', 'icon_name');
select col_hasnt_default('campsite_type_feature', 'icon_name');

select has_column('campsite_type_feature', 'name');
select col_type_is('campsite_type_feature', 'name', 'text');
select col_not_null('campsite_type_feature', 'name');
select col_hasnt_default('campsite_type_feature', 'name');

select has_column('campsite_type_feature', 'position');
select col_type_is('campsite_type_feature', 'position', 'integer');
select col_not_null('campsite_type_feature', 'position');
select col_has_default('campsite_type_feature', 'position');
select col_default_is('campsite_type_feature', 'position', '2147483647');


set client_min_messages to warning;
truncate campsite_type_feature cascade;
truncate campsite_type cascade;
truncate media cascade;
truncate media_content cascade;
truncate company_host cascade;
truncate company_user cascade;
truncate company cascade;
truncate auth."user" cascade;
reset client_min_messages;

insert into auth."user" (user_id, email, name, password, cookie, cookie_expires_at)
values (1, 'demo@tandem.blog', 'Demo', 'test', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', current_timestamp + interval '1 month')
     , (5, 'admin@tandem.blog', 'Demo', 'test', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', current_timestamp + interval '1 month')
;

insert into company (company_id, business_name, vatin, trade_name, phone, email, web, address, city, province, postal_code, rtc_number, country_code, currency_code, default_lang_tag)
values (2, 'Company 2', 'XX123', '', '555-555-555', 'a@a', '', '', '', '', '', '', 'ES', 'EUR', 'ca')
     , (4, 'Company 4', 'XX234', '', '666-666-666', 'b@b', '', '', '', '', '', '', 'FR', 'USD', 'ca')
;

insert into company_user (company_id, user_id, role)
values (2, 1, 'admin')
     , (4, 5, 'admin')
;

insert into company_host (company_id, host)
values (2, 'co2')
     , (4, 'co4')
;

insert into media_content (media_type, bytes)
values ('image/x-xpixmap', 'static char *s[]={"1 1 1 1","a c #ffffff","a"};')
;

insert into media (media_id, company_id, original_filename, content_hash)
values (6, 2, 'cover2.xpm', sha256('static char *s[]={"1 1 1 1","a c #ffffff","a"};'))
     , (8, 4, 'cover4.xpm', sha256('static char *s[]={"1 1 1 1","a c #ffffff","a"};'))
;

insert into campsite_type (campsite_type_id, company_id, name, media_id, dogs_allowed, max_campers)
values (16, 2, 'Wooden lodge', 6, false, 7)
     , (18, 4, 'Bungalow', 8, false, 6)
;

insert into campsite_type_feature (campsite_type_id, icon_name, name)
values (16, 'information', 'Feature 16.1')
     , (18, 'wifi', 'Feature 18.1')
;

prepare campsite_feature_data as
select campsite_type_id, name
from campsite_type_feature
;

set role guest;
select bag_eq(
	'campsite_feature_data',
	$$ values (16, 'Feature 16.1')
	        , (18, 'Feature 18.1')
	$$,
	'Everyone should be able to list all campsite type features across all companies'
);
reset role;

select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co2');

select lives_ok(
	$$ insert into campsite_type_feature(campsite_type_id, icon_name, name) values (16, 'castle', 'Feature 16.2') $$,
	'Admin from company 2 should be able to insert a new campsite type feature to that company.'
);

select bag_eq(
	'campsite_feature_data',
	$$ values (16, 'Feature 16.1')
	        , (16, 'Feature 16.2')
	        , (18, 'Feature 18.1')
	$$,
	'The new row should have been added'
);

select lives_ok(
	$$ update campsite_type_feature set name = 'Feature 16-2' where campsite_type_id = 16 and name = 'Feature 16.2' $$,
	'Admin from company 2 should be able to update campsite type feature of that company.'
);

select bag_eq(
	'campsite_feature_data',
	$$ values (16, 'Feature 16.1')
	        , (16, 'Feature 16-2')
	        , (18, 'Feature 18.1')
	$$,
	'The row should have been updated.'
);

select lives_ok(
	$$ delete from campsite_type_feature where campsite_type_id = 16 and name = 'Feature 16-2' $$,
	'Admin from company 2 should be able to delete campsite type feature from that company.'
);

select bag_eq(
	'campsite_feature_data',
	$$ values (16, 'Feature 16.1')
	        , (18, 'Feature 18.1')
	$$,
	'The row should have been deleted.'
);

select throws_ok(
	$$ insert into campsite_type_feature (campsite_type_id, icon_name, name) values (18, 'toilet', 'Feature 18.2') $$,
	'42501', 'new row violates row-level security policy for table "campsite_type_feature"',
	'Admin from company 2 should NOT be able to insert new campsite type features to company 4.'
);

select lives_ok(
	$$ update campsite_type_feature set name = 'Feature 18-1' where campsite_type_id = 18 $$,
	'Admin from company 2 should not be able to update campsite types of company 4, but no error if campsite_type_id is not changed.'
);

select bag_eq(
	'campsite_feature_data',
	$$ values (16, 'Feature 16.1')
	        , (18, 'Feature 18.1')
	$$,
	'No row should have been changed.'
);

select throws_ok(
	$$ update campsite_type_feature set campsite_type_id = 18 where campsite_type_id = 16 $$,
	'42501', 'new row violates row-level security policy for table "campsite_type_feature"',
	'Admin from company 2 should NOT be able to move campsite type feature to one of company 4'
);

select lives_ok(
	$$ delete from campsite_type_feature where campsite_type_id = 18 $$,
	'Admin from company 2 should NOT be able to delete campsite type from company 4, but not error is thrown'
);

select bag_eq(
	'campsite_feature_data',
	$$ values (16, 'Feature 16.1')
	        , (18, 'Feature 18.1')
	$$,
	'No row should have been changed'
);

select throws_ok(
	$$ insert into campsite_type_feature (campsite_type_id, icon_name, name) values (16, 'baby', '  ') $$,
	'23514', 'new row for relation "campsite_type_feature" violates check constraint "name_not_empty"',
	'Should not be able to insert campsite type features with a blank name.'
);

reset role;


select *
from finish();

rollback;

