-- Test season
set client_min_messages to warning;
create extension if not exists pgtap;
reset client_min_messages;

begin;

select plan(56);

set search_path to camper, public;

select has_table('season');
select has_pk('season' );
select table_privs_are('season', 'guest', array['SELECT']);
select table_privs_are('season', 'employee', array['SELECT']);
select table_privs_are('season', 'admin', array['SELECT', 'INSERT', 'UPDATE', 'DELETE']);
select table_privs_are('season', 'authenticator', array[]::text[]);

select has_column('season', 'season_id');
select col_is_pk('season', 'season_id');
select col_type_is('season', 'season_id', 'integer');
select col_not_null('season', 'season_id');
select col_hasnt_default('season', 'season_id');

select has_column('season', 'company_id');
select col_is_fk('season', 'company_id');
select fk_ok('season', 'company_id', 'company', 'company_id');
select col_type_is('season', 'company_id', 'integer');
select col_not_null('season', 'company_id');
select col_hasnt_default('season', 'company_id');

select has_column('season', 'slug');
select col_is_unique('season', 'slug');
select col_type_is('season', 'slug', 'uuid');
select col_not_null('season', 'slug');
select col_has_default('season', 'slug');
select col_default_is('season', 'slug', 'gen_random_uuid()');

select has_column('season', 'name');
select col_type_is('season', 'name', 'text');
select col_not_null('season', 'name');
select col_hasnt_default('season', 'name');

select has_column('season', 'color');
select col_type_is('season', 'color', 'integer');
select col_not_null('season', 'color');
select col_has_default('season', 'color');
select col_default_is('season', 'color', '0');

select has_column('season', 'active');
select col_type_is('season', 'active', 'boolean');
select col_not_null('season', 'active');
select col_has_default('season', 'active');
select col_default_is('season', 'active', 'true');

select has_column('season', 'position');
select col_type_is('season', 'position', 'integer');
select col_not_null('season', 'position');
select col_has_default('season', 'position');
select col_default_is('season', 'position', '2147483647');


set client_min_messages to warning;
truncate season cascade;
truncate company_host cascade;
truncate company_user cascade;
truncate company cascade;
truncate auth."user" cascade;
reset client_min_messages;

insert into auth."user" (user_id, email, name, password, cookie, cookie_expires_at)
values (1, 'demo@tandem.blog', 'Demo', 'test', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', current_timestamp + interval '1 month')
     , (5, 'admin@tandem.blog', 'Demo', 'test', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', current_timestamp + interval '1 month')
;

insert into company (company_id, business_name, vatin, trade_name, phone, email, web, address, city, province, postal_code, rtc_number, country_code, currency_code, default_lang_tag)
values (2, 'Company 2', 'XX123', '', '555-555-555', 'a@a', '', '', '', '', '', '', 'ES', 'EUR', 'ca')
     , (4, 'Company 4', 'XX234', '', '666-666-666', 'b@b', '', '', '', '', '', '', 'FR', 'USD', 'ca')
;

insert into company_user (company_id, user_id, role)
values (2, 1, 'admin')
     , (4, 5, 'admin')
;

insert into company_host (company_id, host)
values (2, 'co2')
     , (4, 'co4')
;

insert into season (company_id, name)
values (2, 'Low')
     , (4, 'High')
;

prepare season_data as
select company_id, name
from season
order by company_id, name;

set role guest;
select bag_eq(
	'season_data',
	$$ values (2, 'Low')
	        , (4, 'High')
	$$,
	'Everyone should be able to list all seasons across all companies'
);
reset role;

select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co2');

select lives_ok(
	$$ insert into season(company_id, name) values (2, 'Another type' ) $$,
	'Admin from company 2 should be able to insert a new season to that company.'
);

select bag_eq(
	'season_data',
	$$ values (2, 'Low')
	        , (2, 'Another type')
	        , (4, 'High')
	$$,
	'The new row should have been added'
);

select lives_ok(
	$$ update season set name = 'Another' where company_id = 2 and name = 'Another type' $$,
	'Admin from company 2 should be able to update season of that company.'
);

select bag_eq(
	'season_data',
	$$ values (2, 'Low')
	        , (2, 'Another')
	        , (4, 'High')
	$$,
	'The row should have been updated.'
);

select lives_ok(
	$$ delete from season where company_id = 2 and name = 'Another' $$,
	'Admin from company 2 should be able to delete season from that company.'
);

select bag_eq(
	'season_data',
	$$ values (2, 'Low')
	        , (4, 'High')
	$$,
	'The row should have been deleted.'
);

select throws_ok(
	$$ insert into season (company_id, name) values (4, 'Another type' ) $$,
	'42501', 'new row violates row-level security policy for table "season"',
	'Admin from company 2 should NOT be able to insert new seasons to company 4.'
);

select lives_ok(
	$$ update season set name = 'Nope' where company_id = 4 $$,
	'Admin from company 2 should not be able to update new seasons of company 4, but no error if company_id is not changed.'
);

select bag_eq(
	'season_data',
	$$ values (2, 'Low')
	        , (4, 'High')
	$$,
	'No row should have been changed.'
);

select throws_ok(
	$$ update season set company_id = 4 where company_id = 2 $$,
	'42501', 'new row violates row-level security policy for table "season"',
	'Admin from company 2 should NOT be able to move seasons to company 4'
);

select lives_ok(
	$$ delete from season where company_id = 4 $$,
	'Admin from company 2 should NOT be able to delete seasons from company 4, but not error is thrown'
);

select bag_eq(
	'season_data',
	$$ values (2, 'Low')
	        , (4, 'High')
	$$,
	'No row should have been changed'
);

select throws_ok(
	$$ insert into season (company_id, name) values (2, '  ' ) $$,
	'23514', 'new row for relation "season" violates check constraint "name_not_empty"',
	'Should not be able to insert seasons with a blank name.'
);

reset role;


select *
from finish();

rollback;

