-- Test season_calendar
set client_min_messages to warning;
create extension if not exists pgtap;
reset client_min_messages;

begin;

select plan(29);

set search_path to camper, public;

select has_table('season_calendar');
select has_pk('season_calendar');
select col_is_pk('season_calendar', array['season_id', 'season_range']);
select table_privs_are('season_calendar', 'guest', array['SELECT']);
select table_privs_are('season_calendar', 'employee', array['SELECT']);
select table_privs_are('season_calendar', 'admin', array['SELECT', 'INSERT', 'UPDATE', 'DELETE']);
select table_privs_are('season_calendar', 'authenticator', array[]::text[]);

select has_column('season_calendar', 'season_id');
select col_type_is('season_calendar', 'season_id', 'integer');
select col_not_null('season_calendar', 'season_id');
select col_hasnt_default('season_calendar', 'season_id');

select has_column('season_calendar', 'season_range');
select col_type_is('season_calendar', 'season_range', 'daterange');
select col_not_null('season_calendar', 'season_range');
select col_hasnt_default('season_calendar', 'season_range');


set client_min_messages to warning;
truncate season_calendar cascade;
truncate season cascade;
truncate company_host cascade;
truncate company_user cascade;
truncate company cascade;
truncate auth."user" cascade;
reset client_min_messages;


insert into auth."user" (user_id, email, name, password, cookie, cookie_expires_at)
values (1, 'demo@tandem.blog', 'Demo', 'test', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', current_timestamp + interval '1 month')
     , (5, 'admin@tandem.blog', 'Demo', 'test', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', current_timestamp + interval '1 month')
;

insert into company (company_id, business_name, vatin, trade_name, phone, email, web, address, city, province, postal_code, rtc_number, country_code, currency_code, default_lang_tag)
values (2, 'Company 2', 'XX123', '', '555-555-555', 'a@a', '', '', '', '', '', '', 'ES', 'EUR', 'ca')
     , (4, 'Company 4', 'XX234', '', '666-666-666', 'b@b', '', '', '', '', '', '', 'FR', 'USD', 'ca')
;

insert into company_user (company_id, user_id, role)
values (2, 1, 'admin')
     , (4, 5, 'admin')
;

insert into company_host (company_id, host)
values (2, 'co2')
     , (4, 'co4')
;

insert into season (season_id, company_id, name)
values (7, 2, 'Peak')
     , (8, 4, 'Low')
;

insert into season_calendar (season_id, season_range)
values (7, '[2023-01-01, 2023-02-01)')
     , (8, '[2023-02-01, 2023-03-01)')
;

prepare season_data as
select season_id, lower(season_range)::text
from season_calendar
;

set role guest;
select bag_eq(
	'season_data',
	$$ values (7, '2023-01-01')
	        , (8, '2023-02-01')
	$$,
	'Everyone should be able to list all seasons across all companies'
);
reset role;

select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co2');

select lives_ok(
	$$ insert into season_calendar(season_id, season_range) values (7, '[2023-03-01, 2023-04-01)' ) $$,
	'Admin from company 2 should be able to insert a new season to that company.'
);

select bag_eq(
	'season_data',
	$$ values (7, '2023-01-01')
	        , (7, '2023-03-01')
	        , (8, '2023-02-01')
	$$,
	'The new row should have been added'
);

select lives_ok(
	$$ update season_calendar set season_range = '[2023-04-01, 2023-05-01)' where season_id = 7 and season_range = '[2023-03-01, 2023-04-01)' $$,
	'Admin from company 2 should be able to update season of that company.'
);

select bag_eq(
	'season_data',
	$$ values (7, '2023-01-01')
	        , (7, '2023-04-01')
	        , (8, '2023-02-01')
	$$,
	'The row should have been updated.'
);

select lives_ok(
	$$ delete from season_calendar where season_id = 7 and season_range = '[2023-04-01, 2023-05-01)' $$,
	'Admin from company 2 should be able to delete season from that company.'
);

select bag_eq(
	'season_data',
	$$ values (7, '2023-01-01')
	        , (8, '2023-02-01')
	$$,
	'The row should have been deleted.'
);

select throws_ok(
	$$ insert into season_calendar (season_id, season_range) values (8, '[2023-05-01, 2023-06-01)' ) $$,
	'42501', 'new row violates row-level security policy for table "season_calendar"',
	'Admin from company 2 should NOT be able to insert new seasons to company 4.'
);

select lives_ok(
	$$ update season_calendar set season_range = '[2023-09-01, 2023-10-01)' where season_id = 8 $$,
	'Admin from company 2 should not be able to update new seasons of company 4, but no error if season_id is not changed.'
);

select bag_eq(
	'season_data',
	$$ values (7, '2023-01-01')
	        , (8, '2023-02-01')
	$$,
	'No row should have been changed.'
);

select throws_ok(
	$$ update season_calendar set season_id = 8 where season_id = 7 $$,
	'42501', 'new row violates row-level security policy for table "season_calendar"',
	'Admin from company 2 should NOT be able to move seasons to company 4'
);

select lives_ok(
	$$ delete from season_calendar where season_id = 8 $$,
	'Admin from company 2 should NOT be able to delete seasons from company 4, but not error is thrown'
);

select bag_eq(
	'season_data',
	$$ values (7, '2023-01-01')
	        , (8, '2023-02-01')
	$$,
	'No row should have been changed'
);

select throws_ok(
	$$ insert into season_calendar (season_id, season_range) values (7, '[2023-01-30, 2023-02-02)' ) $$,
	'23P01', 'conflicting key value violates exclusion constraint "disallow_overlap"',
	'Should not be able to insert seasons with overlapping range.'
);

reset role;

select *
from finish();

rollback;

