-- Test service
set client_min_messages to warning;
create extension if not exists pgtap;
reset client_min_messages;

begin;

select plan(45);

set search_path to camper, public;

select has_table('service');
select has_pk('service');
select table_privs_are('service', 'guest', array['SELECT']);
select table_privs_are('service', 'employee', array['SELECT']);
select table_privs_are('service', 'admin', array['SELECT', 'INSERT', 'UPDATE', 'DELETE']);
select table_privs_are('service', 'authenticator', array[]::text[]);

select has_column('service', 'service_id');
select col_is_pk('service', 'service_id');
select col_type_is('service', 'service_id', 'integer');
select col_not_null('service', 'service_id');
select col_hasnt_default('service', 'service_id');

select has_column('service', 'company_id');
select col_is_fk('service', 'company_id');
select fk_ok('service', 'company_id', 'company', 'company_id');
select col_type_is('service', 'company_id', 'integer');
select col_not_null('service', 'company_id');
select col_hasnt_default('service', 'company_id');

select has_column('service', 'icon_name');
select col_is_fk('service', 'icon_name');
select fk_ok('service', 'icon_name', 'icon', 'icon_name');
select col_type_is('service', 'icon_name', 'text');
select col_not_null('service', 'icon_name');
select col_hasnt_default('service', 'icon_name');

select has_column('service', 'name');
select col_type_is('service', 'name', 'text');
select col_not_null('service', 'name');
select col_hasnt_default('service', 'name');

select has_column('service', 'description');
select col_type_is('service', 'description', 'xml');
select col_not_null('service', 'description');
select col_hasnt_default('service', 'description');


set client_min_messages to warning;
truncate service cascade;
truncate company_host cascade;
truncate company_user cascade;
truncate company cascade;
truncate auth."user" cascade;
reset client_min_messages;

insert into auth."user" (user_id, email, name, password, cookie, cookie_expires_at)
values (1, 'demo@tandem.blog', 'Demo', 'test', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', current_timestamp + interval '1 month')
     , (5, 'admin@tandem.blog', 'Demo', 'test', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', current_timestamp + interval '1 month')
;

insert into company (company_id, business_name, vatin, trade_name, phone, email, web, address, city, province, postal_code, rtc_number, country_code, currency_code, default_lang_tag)
values (2, 'Company 2', 'XX123', '', '555-555-555', 'a@a', '', '', '', '', '', '', 'ES', 'EUR', 'ca')
     , (4, 'Company 4', 'XX234', '', '666-666-666', 'b@b', '', '', '', '', '', '', 'FR', 'USD', 'ca')
;

insert into company_user (company_id, user_id, role)
values (2, 1, 'admin')
     , (4, 5, 'admin')
;

insert into company_host (company_id, host)
values (2, 'co2')
     , (4, 'co4')
;

insert into service (company_id, icon_name, name, description)
values (2, 'information', 'Information', '')
     , (4, 'wifi', 'WiFi', '')
;

prepare service_data as
select company_id, name
from service
order by company_id, name;

set role guest;
select bag_eq(
	'service_data',
	$$ values (2, 'Information')
	        , (4, 'WiFi')
	$$,
	'Everyone should be able to list all services across all companies'
);
reset role;

select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co2');

select lives_ok(
	$$ insert into service(company_id, icon_name, name, description) values (2, 'restaurant', 'Restaurant', '') $$,
	'Admin from company 2 should be able to insert a new services to that company.'
);

select bag_eq(
	'service_data',
	$$ values (2, 'Information')
	        , (2, 'Restaurant')
	        , (4, 'WiFi')
	$$,
	'The new row should have been added'
);

select lives_ok(
	$$ update service set name = 'Bar' where company_id = 2 and name = 'Restaurant' $$,
	'Admin from company 2 should be able to update services of that company.'
);

select bag_eq(
	'service_data',
	$$ values (2, 'Information')
	        , (2, 'Bar')
	        , (4, 'WiFi')
	$$,
	'The row should have been updated.'
);

select lives_ok(
	$$ delete from service where company_id = 2 and name = 'Bar' $$,
	'Admin from company 2 should be able to delete services from that company.'
);

select bag_eq(
	'service_data',
	$$ values (2, 'Information')
	        , (4, 'WiFi')
	$$,
	'The row should have been deleted.'
);

select throws_ok(
	$$ insert into service (company_id, icon_name, name, description) values (4, 'store', 'Store', '') $$,
	'42501', 'new row violates row-level security policy for table "service"',
	'Admin from company 2 should NOT be able to insert new services to company 4.'
);

select lives_ok(
	$$ update service set name = 'Nope' where company_id = 4 $$,
	'Admin from company 2 should not be able to update new services of company 4, but no error if company_id is not changed.'
);

select bag_eq(
	'service_data',
	$$ values (2, 'Information')
	        , (4, 'WiFi')
	$$,
	'No row should have been changed.'
);

select throws_ok(
	$$ update service set company_id = 4 where company_id = 2 $$,
	'42501', 'new row violates row-level security policy for table "service"',
	'Admin from company 2 should NOT be able to move services to company 4'
);

select lives_ok(
	$$ delete from service where company_id = 4 $$,
	'Admin from company 2 should NOT be able to delete services from company 4, but not error is thrown'
);

select bag_eq(
	'service_data',
	$$ values (2, 'Information')
	        , (4, 'WiFi')
	$$,
	'No row should have been changed'
);

select throws_ok(
	$$ insert into service (company_id, icon_name, name, description) values (2, 'toilet', '  ', '') $$,
	'23514', 'new row for relation "service" violates check constraint "name_not_empty"',
	'Should not be able to insert services with a blank name.'
);

reset role;


select *
from finish();

rollback;

