-- Test set_cookie
set client_min_messages to warning;
create extension if not exists pgtap;
reset client_min_messages;

begin;

select plan(17);

set search_path to auth, camper, public;

select has_function('public', 'set_cookie', array ['text', 'text']);
select function_lang_is('public', 'set_cookie', array ['text', 'text'], 'sql');
select function_returns('public', 'set_cookie', array ['text', 'text'], 'void');
select isnt_definer('public', 'set_cookie', array ['text', 'text']);
select volatility_is('public', 'set_cookie', array ['text', 'text'], 'stable');
select function_privs_are('public', 'set_cookie', array ['text', 'text'], 'guest', array []::text[]);
select function_privs_are('public', 'set_cookie', array ['text', 'text'], 'employee', array []::text[]);
select function_privs_are('public', 'set_cookie', array ['text', 'text'], 'admin', array []::text[]);
select function_privs_are('public', 'set_cookie', array ['text', 'text'], 'authenticator', array ['EXECUTE']);

set client_min_messages to warning;
truncate company_host cascade;
truncate company_user cascade;
truncate company cascade;
truncate auth."user" cascade;
reset client_min_messages;

insert into auth."user" (user_id, email, name, password, cookie, cookie_expires_at)
values (1, 'demo@tandem.blog', 'Demo', 'test', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', current_timestamp + interval '1 month')
     , (5, 'admin@tandem.blog', 'Demo', 'test', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', current_timestamp + interval '1 month')
;

insert into company (company_id, business_name, vatin, trade_name, phone, email, web, address, city, province, postal_code, rtc_number, country_code, currency_code, default_lang_tag)
values (2, 'Company 2', 'XX123', '', '555-555-555', 'a@a', '', '', '', '', '', '', 'ES', 'EUR', 'ca')
     , (4, 'Company 4', 'XX234', '', '666-666-666', 'b@b', '', '', '', '', '', '', 'FR', 'USD', 'es')
;

insert into company_user (company_id, user_id, role)
values (2, 1, 'employee')
     , (4, 5, 'admin')
;

insert into company_host (company_id, host)
values (2, 'co2')
     , (4, 'co4')
;

prepare user_info as
select current_user_email(), current_user_cookie(), current_company_id(), current_user;

select lives_ok(
	$$ select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co2') $$,
	'Should run ok for a valid cookie'
);

select results_eq(
	'user_info',
	$$ values ('demo@tandem.blog', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', 2, 'employee'::name) $$,
	'Should have updated the info with the correct user'
);

reset role;

select lives_ok(
	$$ select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co4') $$,
	'Should run ok for a valid cookie, even for the wrong company'
);

select results_eq(
	'user_info',
	$$ values ('', '', 0, 'guest'::name) $$,
	'Should have updated the info as a guest user for this company'
);

reset role;

select lives_ok(
	$$ select set_cookie('12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524/admin@tandem.blog', 'co4') $$,
	'Should run ok for a different cookie'
);

select results_eq(
	'user_info',
	$$ values ('admin@tandem.blog', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', 4, 'admin'::name) $$,
	'Should have updated the info with the other user'
);

reset role;

select lives_ok(
	$$ select set_cookie('aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/admin@tandem.blog', 'asth') $$,
	'Should run ok even for an invalid cookie'
);

select results_eq(
	'user_info',
	$$ values ('', '', 0, 'guest'::name) $$,
	'Should have updated the info as a guest user'
);

reset role;

select *
from finish();

rollback;
